#ifndef IPPBASE_H
#define IPPBASE_H

#include <QVariantMap>
#include <QMap>
#include <cups/ipp.h>
#include <cups/cups.h>
#include "fly-admin-printer_export.h"

namespace Cups {

class FLY_ADMIN_PRINTER_EXPORT IppBase
{
public:
    IppBase();
    virtual ~IppBase();

    ipp_t *handle();
    bool isNull() const;

    ipp_state_t state() const;
    void setState(ipp_state_t state);

    ipp_attribute_t *firstAttribute() const;
    ipp_attribute_t *nextAttribute() const;
    const QList<QVariantMap> &attributes() const;
    QVariant attribute(int record, const QString &name, const QVariant &defaultValue = QVariant()) const;
    bool hasAttribute(int record, const QString &name) const;
    QMap <QString, ipp_tag_t> valueTags() const;
    QMap <QString, ipp_tag_t> groupTags() const;

    void addAttribute(const QString &name, ipp_tag_t tag, const QStringList &values);
    void addAttribute(const QString &name, ipp_tag_t tag, const QString &value);
    void addAttribute(const QString &name, ipp_tag_t tag, int numValues, const char * const *values);
    void addPrinterAttribute(const QString &name, ipp_tag_t tag, const QString &value);
    void addPrinterAttribute(const QString &name, ipp_tag_t tag, const QStringList &values);
    void addPrinterAttribute(const QString &name, int value);
    void addJobAttribute(const QString &name, ipp_tag_t tag, const QString &value);
    void addJobAttribute(const QString &name, int value);
    void addAttribute(const QString &name, int value);
    void addAttribute(ipp_tag_t tag, const QString &name, int value);
    void addAttribute(const QString &name, bool value);
    void addSubscriptionAttribute(const QString &name, ipp_tag_t tag, const QString &value);
    void addSubscriptionAttribute(const QString &name, int value);

protected:
    void clearCache() const;
    ipp_t *m_ipp = nullptr;

private:
    mutable QList <QVariantMap> m_attributeCache;
};

}

#endif // IPPBASE_H
