#ifndef IPPVALUE_H
#define IPPVALUE_H

#include <QVariant>
#include <QDateTime>
#include <cups/ipp.h>
#include "fly-admin-printer_export.h"

namespace Cups {

class FLY_ADMIN_PRINTER_EXPORT IppValue
{
public:
    explicit IppValue(ipp_attribute_t *attribute, int element);

    struct Resolution
    {

        Resolution();
        Resolution(int w, int h, ipp_res_t u);
        Resolution(const QVariant &src);
        operator QVariant() const;

        int width = 0, height = 0;
        ipp_res_t units = IPP_RES_PER_INCH;

    };
    struct Range
    {
        Range(int min, int max);
        Range(const QVariant &src);
        bool isNull() const;
        operator QVariant() const;
        int min = 0, max = 0;
    };
    int toInt() const;
    bool toBool() const;
    QDateTime toDateTime() const;
    Resolution toResolution() const;
    Range toRange() const;
    QString toString() const;
    QVariant convert() const;

private:
    ipp_attribute_t *m_attribute;
    int m_element;
};

}

#endif // IPPVALUE_H
