#ifndef __JOBWIDGET_H
#define __JOBWIDGET_H

#include <QTreeWidget>
#include <QPointer>
#include <QMap>
#include "fly-admin-printer_export.h"

class QAction;
class QMenu;
class QTimer;
class SecurityJobAction;

namespace Cups
{
class Connection;
class Job;
}

class FLY_ADMIN_PRINTER_EXPORT JobWidget: public QTreeWidget
{
    Q_OBJECT
public:
    enum Action {
        HoldReleaseAction = 0,
        CancelAction,
        RestartAction,
        AuthAction,
        PurgeAction,
        ShowCompletedAction,
        ShowCanceledAction,
        ShowAbortedAction,
        ShowAttributesAction
    };

    JobWidget(QWidget *parent = nullptr);
    ~JobWidget();

    void load(Cups::Connection *connection, const QString &printer = QString());
    QAction *action(Action id) const;

public slots:
    virtual void currentItemChanged(QTreeWidgetItem*it, QTreeWidgetItem*);
    virtual void reload();

protected:
    virtual void contextMenuEvent(QContextMenuEvent *event) override;
    virtual void keyPressEvent(QKeyEvent *event) override;

protected slots:
    void onJobState(const QString &text, const QString &uri, const QString &name);

private slots:
    virtual void cancelJob();
    virtual void purgeJob();
    virtual void holdReleaseJob();
    virtual void restartJob();
    virtual void authenticateJob();
    virtual void showAttributes();

signals:
    void jobsStateChanged();

private:
    void connectToDBus();
    void disconnectFromDBus();
    void configureItem(QTreeWidgetItem *item, const Cups::Job &job, const QList <QVariantMap> &dests, bool update);
    QTimer *m_refreshTimer;
    QList<SecurityJobAction*> m_extraActions;
    Cups::Connection *m_connection = nullptr;
    QString m_printer;
    QMenu *m_menu;
    QMap<Action, QAction *> m_actions;
};

#endif
